@@ -1,6 +1,6 @@
 package App::Sqitch::Command::help;
 
-use v5.10;
+use v5.10.1;
 use strict;
 use warnings;
 use utf8;
@@ -8,7 +8,7 @@ use Carp;
 use Pod::Find;
 use parent 'App::Sqitch::Command';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # XXX Add --all at some point, to output a list of all possible commands.
 
