@@ -1,5 +1,5 @@
 #!/usr/bin/perl
 
-use v5.10;
+use v5.10.1;
 
 say "@ARGV";
